v2.1.1
======

No significant changes.


v2.1.0
======

Switch to PEP 420 for namespace package. Use importlib_resources
for loading resources.

v2.0.0
======

Switch to `pkgutil namespace technique
<https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages>`_
for the ``jaraco`` namespace.
